==> rest-sdk-commons-0.6.0-sources.jar: com/mulesoft/connectivity/rest/commons/internal/metadatamodel/handler/EnumHandler.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.commons.internal.metadatamodel.handler;

import org.mule.metadata.api.builder.BaseTypeBuilder;
import org.mule.metadata.api.builder.StringTypeBuilder;
import org.mule.metadata.api.builder.TypeBuilder;

import java.util.Set;

import org.everit.json.schema.EnumSchema;
import org.everit.json.schema.Schema;

public class EnumHandler implements SchemaHandler {

  @Override
  public boolean handles(Schema schema) {
    return schema instanceof EnumSchema;
  }

  @Override
  public TypeBuilder<?> handle(Schema schema, BaseTypeBuilder root, RestHandlerManager handlerManager,
                               ParsingContext parsingContext) {
    final EnumSchema enumSchema = (EnumSchema) schema;
    final StringTypeBuilder enumMetadataBuilder = root.stringType();
    final Set<Object> possibleValues = enumSchema.getPossibleValues();
    final String[] stringValues = possibleValues.stream().map((v) -> String.valueOf(v)).toArray(String[]::new);
    enumMetadataBuilder.enumOf(stringValues);
    if (schema.getId() != null) {
      enumMetadataBuilder.id(schema.getId());
    }
    return enumMetadataBuilder;
  }
}

==> rest-sdk-commons-0.10.0-sources.jar: com/mulesoft/connectivity/rest/commons/internal/metadatamodel/handler/EnumHandler.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.commons.internal.metadatamodel.handler;

import org.mule.metadata.api.builder.BaseTypeBuilder;
import org.mule.metadata.api.builder.StringTypeBuilder;
import org.mule.metadata.api.builder.TypeBuilder;

import com.mulesoft.connectivity.rest.commons.internal.util.RestSdkUtils;

import java.util.Set;

import org.everit.json.schema.EnumSchema;
import org.everit.json.schema.Schema;

public class EnumHandler implements SchemaHandler {

  @Override
  public boolean handles(Schema schema) {
    return schema instanceof EnumSchema;
  }

  @Override
  public TypeBuilder<?> handle(Schema schema, BaseTypeBuilder root, RestHandlerManager handlerManager,
                               ParsingContext parsingContext) {
    final EnumSchema enumSchema = (EnumSchema) schema;
    final StringTypeBuilder enumMetadataBuilder = root.stringType();
    processTracing(schema, enumMetadataBuilder, handlerManager, parsingContext);
    final Set<Object> possibleValues = enumSchema.getPossibleValues();
    final String[] stringValues = possibleValues.stream().map(RestSdkUtils::stringValue).toArray(String[]::new);
    enumMetadataBuilder.enumOf(stringValues);
    if (schema.getId() != null) {
      enumMetadataBuilder.id(schema.getId());
    }
    return enumMetadataBuilder;
  }
}
